@@ -6,8 +6,8 @@
 ;; Author: Boris Buliga <boris@d12frosted.io>
 ;; Maintainer: Boris Buliga <boris@d12frosted.io>
 ;; URL: https://github.com/d12frosted/vulpea-ui
-;; Package-Version: 20260106.738
-;; Package-Revision: 923975fb209d
+;; Package-Version: 20260118.1232
+;; Package-Revision: 2b07223f4e40
 ;; Package-Requires: ((emacs "29.1") (vulpea "2.0.0") (vui "0.1"))
 ;; Keywords: outlines hypermedia
 
@@ -54,6 +54,7 @@
 (require 'org-element)
 (require 'vulpea)
 (require 'vui)
+(require 'vui-components)
 
 
 ;;; Custom variables
@@ -599,27 +600,17 @@ For use within widget components."
 TITLE is the widget title string.
 COUNT is an optional count to display in the header.
 CHILDREN (implicit) is a function returning the widget content."
-  :state ((collapsed vulpea-ui-default-widget-collapsed))
   :render
-  (vui-vstack
-   :spacing 0
-   ;; Header
-   (vui-hstack
-    :spacing 1
-    (vui-button (if collapsed "▶" "▼")
-      :on-click (lambda () (vui-set-state :collapsed (not collapsed)))
-      :face 'vulpea-ui-widget-header-face
-      :help-echo nil)
-    (vui-text title :face 'vulpea-ui-widget-header-face)
-    (when count
-      (vui-text (format "(%s)" count) :face 'vulpea-ui-widget-count-face)))
-   ;; Content (when not collapsed)
-   (unless collapsed
-     (when children
-       (vui-vstack
-        :spacing 0
-        :indent 2
-        (funcall children))))))
+  (let ((display-title (if count
+                           (format "%s (%s)" title count)
+                         title)))
+    (vui-collapsible
+      :title display-title
+      :initially-expanded (not vulpea-ui-default-widget-collapsed)
+      :title-face 'vulpea-ui-widget-header-face
+      :indent 2
+      (when children
+        (funcall children)))))
 
 
 ;;; Shared components
@@ -763,7 +754,7 @@ Otherwise reads from disk."
                  (lambda (heading)
                    (vulpea-ui--render-outline-heading heading note))
                  headings)
-              (vui-text "No headings" :face 'shadow))))))))
+              (vui-muted "No headings"))))))))
 
 (defun vulpea-ui--heading-archived-p (hl archive-tag)
   "Return non-nil if HL or any of its ancestors has ARCHIVE-TAG."
@@ -837,19 +828,20 @@ Groups backlinks by file and shows heading context with optional previews."
                        (vulpea-ui--get-grouped-backlinks note)))
              (groups (plist-get result :groups))
              (filtered-count (plist-get result :filtered-count))
-             (total-count (plist-get result :total-count)))
+             (total-count (plist-get result :total-count))
+             (count-display (if (= filtered-count total-count)
+                                filtered-count
+                              (format "%d/%d" filtered-count total-count))))
         (vui-component 'vulpea-ui-widget
           :title "Backlinks"
-          :count (if (= filtered-count total-count)
-                     filtered-count
-                   (format "%d/%d" filtered-count total-count))
+          :count count-display
           :children
           (lambda ()
             (if groups
                 (vui-vstack
                  :spacing 1
                  (seq-map #'vulpea-ui--render-backlink-group groups))
-              (vui-text "No backlinks" :face 'shadow))))))))
+              (vui-muted "No backlinks"))))))))
 
 (defun vulpea-ui--get-grouped-backlinks (note)
   "Get backlinks to NOTE grouped by file.
@@ -1206,7 +1198,7 @@ This is an internal wrapper around `vulpea-ui-clean-org-markup'."
      ;; File-level note link
      (if file-note
          (vui-component 'vulpea-ui-note-link :note file-note)
-       (vui-text (file-name-nondirectory path) :face 'shadow))
+       (vui-muted (file-name-nondirectory path)))
      ;; Mentions grouped by heading
      (when grouped
        (vui-vstack
@@ -1359,7 +1351,7 @@ Renders the preview as a clickable button to jump to the mention."
                        (vui-text (format "(%d)" count)
                          :face 'vulpea-ui-widget-count-face))))
                   forward-links))
-              (vui-text "No links" :face 'shadow))))))))
+              (vui-muted "No links"))))))))
 
 (defun vulpea-ui--get-forward-links (note)
   "Get all notes linked from NOTE's file with counts.
@@ -1407,7 +1399,7 @@ Returns a list of plists with :note and :count, sorted by title."
            (seq-map (lambda (widget-sym)
                       (vui-component widget-sym :key widget-sym))
                     widgets)))
-      (vui-text "No vulpea note selected" :face 'shadow))))
+      (vui-muted "No vulpea note selected"))))
 
 (vui-defcomponent vulpea-ui-sidebar-root (note)
   "Root component for the sidebar with NOTE context."
